Crate yellowstone_vixen_core

Crate yellowstone_vixen_core 

This crate provides the core components necessary for implementing parsers for the yellowstone-vixen family of crates. This crate should be used as a dependency instead of yellowstone-vixen for crates that intend to define and export Vixen parsers as libraries without needing to access the runtime functionality of Vixen.

Re-exports

pub extern crate bs58;

Modules

instruction
Helpers for parsing transaction updates into instructions.

Macros

pubkey_convert_helpers
Helper macro for converting Vixen’s Pubkey to a Solana ed25519 public key.

Structs

AccountPrefilter
A prefilter for matching accounts.
BlockMetaPrefilter
A prefilter for matching block metadata updates.
BlockPrefilter
A prefilter for matching block updates.
Filters
A collection of filters for a Vixen subscription.
InstructionUpdateOutput
Generic output type for instruction parsers that wraps shared data for all instructions in the given transaction.
KeyBytes
Generic wrapper for a fixed-length array of cryptographic key bytes, convertible to or from a base58-encoded string.
Prefilter
A prefilter for narrowing down the updates that a parser will receive.
PrefilterBuilder
A builder for constructing a prefilter.
SlotPrefilter
A prefilter for matching slot updates updates.
TransactionPrefilter
A prefilter for matching transactions.

Enums

CommitmentLevel
Type mirroring the CommitmentLevel enum in the geyser crate but serializable. Used to avoid need for custom deserialization logic.
KeyFromStrError
An error that can occur when parsing a key from a base58 string.
ParseError
An error returned by a Vixen parser
PrefilterError
An error that can occur when building a prefilter.

Traits

GetPrefilter
Helper trait for getting the prefilter of a parser.
Parser
A core trait that defines the parse logic for producing a parsed value from a Vixen update (typically AccountUpdate, TransactionUpdate, or InstructionUpdate).
ParserId
Helper trait for getting the ID of a parser.
ProgramParser
A parser that parses all relevant updates for a particular program ID.

Type Aliases

AccountUpdate
An account update from Yellowstone.
AccountUpdateInfo
An account update from Yellowstone.
BlockMetaUpdate
A block meta update from Yellowstone.
BlockUpdate
A block update from Yellowstone.
ParseResult
The result of parsing an update.
Pubkey
Helper type representing a Solana public key.
SlotUpdate
A slot update from Yellowstone.
TransactionUpdate
A transaction update from Yellowstone.