This crate provides the core components necessary for implementing parsers
for the yellowstone-vixen family of crates. This crate should be used
as a dependency instead of yellowstone-vixen for crates that intend to
define and export Vixen parsers as libraries without needing to access the
runtime functionality of Vixen.
Re-exports
pub extern crate bs58;
Modules
- instruction
- Helpers for parsing transaction updates into instructions.
Macros
- pubkey_
convert_ helpers - Helper macro for converting Vixen’s
Pubkeyto a Solana ed25519 public key.
Structs
- Account
Prefilter - A prefilter for matching accounts.
- Block
Meta Prefilter - A prefilter for matching block metadata updates.
- Block
Prefilter - A prefilter for matching block updates.
- Filters
- A collection of filters for a Vixen subscription.
- Instruction
Update Output - Generic output type for instruction parsers that wraps shared data for all instructions in the given transaction.
- KeyBytes
- Generic wrapper for a fixed-length array of cryptographic key bytes, convertible to or from a base58-encoded string.
- Prefilter
- A prefilter for narrowing down the updates that a parser will receive.
- Prefilter
Builder - A builder for constructing a prefilter.
- Slot
Prefilter - A prefilter for matching slot updates updates.
- Transaction
Prefilter - A prefilter for matching transactions.
Enums
- Commitment
Level - Type mirroring the
CommitmentLevelenum in thegeysercrate but serializable. Used to avoid need for custom deserialization logic. - KeyFrom
StrError - An error that can occur when parsing a key from a base58 string.
- Parse
Error - An error returned by a Vixen parser
- Prefilter
Error - An error that can occur when building a prefilter.
Traits
- GetPrefilter
- Helper trait for getting the prefilter of a parser.
- Parser
- A core trait that defines the parse logic for producing a parsed value from
a Vixen update (typically
AccountUpdate,TransactionUpdate, orInstructionUpdate). - Parser
Id - Helper trait for getting the ID of a parser.
- Program
Parser - A parser that parses all relevant updates for a particular program ID.
Type Aliases
- Account
Update - An account update from Yellowstone.
- Account
Update Info - An account update from Yellowstone.
- Block
Meta Update - A block meta update from Yellowstone.
- Block
Update - A block update from Yellowstone.
- Parse
Result - The result of parsing an update.
- Pubkey
- Helper type representing a Solana public key.
- Slot
Update - A slot update from Yellowstone.
- Transaction
Update - A transaction update from Yellowstone.